import { LogMessageParams, TextDocumentIdentifier, TextDocumentItem } from 'vscode-languageserver';
import { MessageEmitter, MessageWriter } from './connection';
import { TextDocumentContentParams, WorkspaceFilesParams } from './request-type';
/**
 * Provides an interface to call methods on the remote client.
 * Methods are named after the camelCase version of the LSP method name
 */
export declare class RemoteLanguageClient {
    private input;
    private output;
    /** The next request ID to use */
    private idCounter;
    /**
     * @param input MessageEmitter to listen on for responses
     * @param output MessageWriter to write requests/notifications to
     */
    constructor(input: MessageEmitter, output: MessageWriter);
    /**
     * Sends a Request
     *
     * @param method The method to call
     * @param params The params to pass to the method
     * @return Emits the value of the result field or the error
     */
    private request(method, params);
    /**
     * Sends a Notification
     *
     * @param method The method to notify
     * @param params The params to pass to the method
     */
    private notify(method, params);
    /**
     * The content request is sent from a server to a client to request the
     * current content of a text document identified by the URI
     */
    textDocumentXcontent(params: TextDocumentContentParams): Promise<TextDocumentItem>;
    /**
     * Returns a list of all files in a directory
     */
    workspaceXfiles(params: WorkspaceFilesParams): Promise<TextDocumentIdentifier[]>;
    /**
     * The log message notification is sent from the server to the client to ask
     * the client to log a particular message.
     */
    windowLogMessage(params: LogMessageParams): void;
}
